From 49c4277654080a2073b2e83d668d5f3635a20877 Mon Sep 17 00:00:00 2001
From: DL1YCF <dl1ycf@darc.de>
Date: Thu, 15 Oct 2020 21:29:26 +0200
Subject: [PATCH] small correction

---
 midi3.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/midi3.c b/midi3.c
index 3baec72..f034404 100644
--- a/midi3.c
+++ b/midi3.c
@@ -610,9 +610,9 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
 	case MIDI_ACTION_MEM_RECALL_M3:
 	case MIDI_ACTION_MEM_RECALL_M4:
             //
 	    // only knob supported
             //
-            if (type == MIDI_TYPE_KNOB) {
+            if (type == MIDI_TYPE_KEY) {
                 new = action - MIDI_ACTION_MEM_RECALL_M0,
 		g_idle_add(ext_recall_memory_slot, GINT_TO_POINTER(new));
 	    }
@@ -747,11 +747,11 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
 	case MIDI_ACTION_MEM_STORE_M3:
 	case MIDI_ACTION_MEM_STORE_M4:
             //
 	    // only knob supported
             //
-            if (type == MIDI_TYPE_KNOB) {
+            if (type == MIDI_TYPE_KEY) {
                 new = action - MIDI_ACTION_MEM_STORE_M0;
-		g_idle_add(ext_recall_memory_slot, GINT_TO_POINTER(new));
+		g_idle_add(ext_store_memory_slot, GINT_TO_POINTER(new));
 	    }
             break;
 	/////////////////////////////////////////////////////////// "SWAPRX"
@@ -610,9 +610,9 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
 	case MIDI_ACTION_MEM_RECALL_M4:
             //
-	    // only knob supported
+	    // only key supported
             //
@@ -747,11 +747,11 @@ void DoTheMidi(enum MIDIaction action, enum MIDItype type, int val) {
 	case MIDI_ACTION_MEM_STORE_M4:
             //
-	    // only knob supported
+	    // only key supported
             //
-- 
2.45.2